'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
const pandora_service_logger_1 = require("pandora-service-logger");
const path_1 = require("path");
const os_1 = require("os");
const ConsoleLogger = require('egg-logger').EggConsoleLogger;
exports.consoleLogger = new ConsoleLogger({
    level: 'INFO',
});
let daemonLogger = null;
function getDaemonLogger() {
    const { logger: loggerConfig } = lazyGetGlobalConfig();
    if (!daemonLogger) {
        const loggerManager = pandora_service_logger_1.DefaultLoggerManager.getInstance();
        daemonLogger = loggerManager.createLogger('daemon', Object.assign({}, loggerConfig.daemonLogger, { dir: path_1.join(loggerConfig.logsDir, 'pandorajs') }));
    }
    return daemonLogger;
}
exports.getDaemonLogger = getDaemonLogger;
function getDaemonStdoutLogPath() {
    const { logger: loggerConfig } = lazyGetGlobalConfig();
    return path_1.join(loggerConfig.logsDir, 'pandorajs/daemon_std.log');
}
exports.getDaemonStdoutLogPath = getDaemonStdoutLogPath;
function getDaemonLogPath() {
    const { logger: loggerConfig } = lazyGetGlobalConfig();
    return path_1.join(loggerConfig.logsDir, 'pandorajs/daemon.log');
}
exports.getDaemonLogPath = getDaemonLogPath;
function createAppLogger(appName, logName) {
    const { logger: loggerConfig } = lazyGetGlobalConfig();
    const loggerManager = pandora_service_logger_1.DefaultLoggerManager.getInstance();
    return loggerManager.createLogger(logName, Object.assign({}, loggerConfig.appLogger, { dir: path_1.join(loggerConfig.logsDir, appName) }));
}
exports.createAppLogger = createAppLogger;
function getAppLogPath(appName, logName) {
    const { logger: loggerConfig } = lazyGetGlobalConfig();
    return path_1.join(loggerConfig.logsDir, appName, logName + '.log');
}
exports.getAppLogPath = getAppLogPath;
const eolReg = new RegExp(os_1.EOL + '$');
function removeEOL(str) {
    eolReg.lastIndex = 0;
    return str.replace(eolReg, '');
}
exports.removeEOL = removeEOL;
/**
 * Prevent cycle dependencies
 * @return {any}
 */
function lazyGetGlobalConfig() {
    const globalConfigProcessor = require('./GlobalConfigProcessor').GlobalConfigProcessor.getInstance();
    return globalConfigProcessor.getAllProperties();
}
//# sourceMappingURL=LoggerBroker.js.map